@@ -1,14 +1,17 @@
 #!/bin/env python
+import os
 from flask import Flask
 from flask_sqlalchemy import SQLAlchemy
-from flask_script import Manager
-from flask_migrate import Migrate, MigrateCommand
+from flask_migrate import Migrate
+
+basedir = os.path.abspath(os.path.dirname(__file__))
 
 app = Flask(__name__)
-app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:///app1.db'
+app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:///' + os.path.join(
+    basedir, 'app1.db')
 app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
 app.config['SQLALCHEMY_BINDS'] = {
-    "db1": "sqlite:///app2.db",
+    "db1": "sqlite:///" + os.path.join(basedir, "app2.db"),
 }
 
 db = SQLAlchemy(app)
@@ -27,16 +30,14 @@ class Group(db.Model):
 
 migrate = Migrate(app, db)
 
-manager = Manager(app)
-manager.add_command('db', MigrateCommand)
 
-
-@manager.command
+@app.cli.command()
 def add():
+    """Add test users."""
     db.session.add(User(name='test'))
     db.session.add(Group(name='group'))
     db.session.commit()
 
 
 if __name__ == '__main__':
-    manager.run()
+    app.run()
